@@ -1,5 +1,3 @@
-context("tibble")
-
 test_that("tibble returns correct number of rows with all combinatinos", {
   expect_equal(nrow(tibble(value = 1:10)), 10L)
   expect_equal(nrow(tibble(value = 1:10, name = "recycle_me")), 10L)
@@ -72,7 +70,7 @@ test_that("missing names are imputed from call", {
 
 test_that("empty input makes 0 x 0 tbl_df", {
   zero <- tibble()
-  expect_is(zero, "tbl_df")
+  expect_s3_class(zero, "tbl_df")
   expect_equal(dim(zero), c(0L, 0L))
   expect_identical(attr(zero, "names"), character(0L))
 })
@@ -181,14 +179,14 @@ test_that("columns must be same length", {
 
 test_that("empty list() makes 0 x 0 tbl_df", {
   zero <- as_tibble(list())
-  expect_is(zero, "tbl_df")
+  expect_s3_class(zero, "tbl_df")
   expect_equal(dim(zero), c(0L, 0L))
 })
 
 
 test_that("NULL makes 0 x 0 tbl_df", {
   nnnull <- as_tibble(NULL)
-  expect_is(nnnull, "tbl_df")
+  expect_s3_class(nnnull, "tbl_df")
   expect_equal(dim(nnnull), c(0L, 0L))
 })
 
@@ -315,14 +313,18 @@ test_that("as_tibble() makes names `minimal`, even if not fixing names", {
 })
 
 test_that("as_tibble() implements unique names", {
-  invalid_df <- as_tibble(list(3, 4, 5), .name_repair = "unique")
+  suppressMessages(
+    invalid_df <- as_tibble(list(3, 4, 5), .name_repair = "unique")
+  )
   expect_equal(length(invalid_df), 3)
   expect_equal(nrow(invalid_df), 1)
   expect_equal(names(invalid_df), unique_names(rep("", 3)))
 })
 
 test_that("as_tibble() implements universal names", {
-  invalid_df <- as_tibble(list(3, 4, 5), .name_repair = "universal")
+  suppressMessages(
+    invalid_df <- as_tibble(list(3, 4, 5), .name_repair = "universal")
+  )
   expect_equal(length(invalid_df), 3)
   expect_equal(nrow(invalid_df), 1)
   expect_equal(names(invalid_df), universal_names(rep("", 3)))
@@ -383,7 +385,7 @@ test_that("as_tibble.matrix() supports .name_repair", {
     rep("", 2)
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     paste0("...", 1:2)
   )
 
@@ -398,7 +400,7 @@ test_that("as_tibble.matrix() supports .name_repair", {
     c("if", "when")
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     c(".if", "when")
   )
 })
@@ -415,7 +417,7 @@ test_that("as_tibble.poly() supports .name_repair", {
     as.character(1:3)
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     paste0("...", 1:3)
   )
 })
@@ -432,7 +434,7 @@ test_that("as_tibble.table() supports .name_repair", {
     c("a", "a", "n")
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     c("a...1", "a...2", "n")
   )
 
@@ -447,7 +449,7 @@ test_that("as_tibble.table() supports .name_repair", {
     c("if", "when", "n")
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     c(".if", "when", "n")
   )
 
@@ -458,7 +460,7 @@ test_that("as_tibble.table() supports .name_repair", {
     c("m", "n", "n")
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     c("m", "n...2", "n...3")
   )
 })
@@ -475,7 +477,7 @@ test_that("as_tibble.ts() supports .name_repair, minimal by default (#537)", {
     rep("", 2)
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     paste0("...", 1:2)
   )
 
@@ -490,7 +492,7 @@ test_that("as_tibble.ts() supports .name_repair, minimal by default (#537)", {
     c("if", "when")
   )
   expect_identical(
-    names(as_tibble(x, .name_repair = "universal")),
+    names(suppressMessages(as_tibble(x, .name_repair = "universal"))),
     c(".if", "when")
   )
 })
@@ -642,6 +644,8 @@ test_that("`validate` triggers deprecation message, but then works", {
 })
 
 test_that("Consistent `validate` and `.name_repair` used together keep silent.", {
+  skip_legacy()
+
   scoped_lifecycle_warnings()
 
   expect_legacy_error(
@@ -678,6 +682,8 @@ test_that("Consistent `validate` and `.name_repair` used together keep silent.",
 })
 
 test_that("Inconsistent `validate` and `.name_repair` used together raise a warning.", {
+  skip_legacy()
+
   expect_legacy_error(
     expect_warning(
       as_tibble(list(a = 1, "hi"), validate = FALSE, .name_repair = "check_unique"),
